@@ -1,4 +1,4 @@
 from .asset import Asset
-from .exceptions import CheckException
+from .exceptions import CheckException, NoCountException
 from .check import CheckBase, CheckBaseMulti
 from .start import start
