@@ -10,7 +10,7 @@ from thingsdb.room import Room
 from thingsdb.room import event
 from typing import List, Dict, Tuple, Callable, Union, Optional
 from .hub import hub
-from .exceptions import CheckException
+from .exceptions import CheckException, NoCountException
 from .asset import Asset
 from .check import CheckBase, CheckBaseMulti
 
@@ -25,13 +25,15 @@ class ServiceRoom(Room):
 
     def init(self, collector_key: str,
              checks: Tuple[Union[CheckBase, CheckBaseMulti]],
-             on_log_level: Callable[[int], None], no_count: bool = False):
+             on_log_level: Callable[[int], None], no_count: bool = False,
+             max_timeout: float = 300.0):
         self.collector_key = collector_key
         self._checks = {check.key: check for check in checks}
         self._last = int(time.time())-1
         self._scheduled: Dict[int, Dict[int, dict]] = defaultdict(dict)
         self._on_log_level = on_log_level
         self._no_count = no_count
+        self._max_timeout = max_timeout
 
     async def load_all(self):
         self._query = functools.partial(self.client.query, scope=self.scope)
@@ -90,9 +92,10 @@ class ServiceRoom(Room):
             await self._load(cid)
 
     async def _send_to_hub(self, asset: Asset, result: Optional[dict],
-                           error: Optional[dict], ts: float):
+                           error: Optional[dict], ts: float, no_count: bool):
         if error:
-            logging.error(error)
+            logging.error(f'Error: {error}; {asset}')
+
         path = asset.asset_id, asset.check_id
         check_data = {
             'result': result,
@@ -100,7 +103,7 @@ class ServiceRoom(Room):
             'framework': {
                 'duration': time.time() - ts,
                 'timestamp': int(ts),
-                'no_count': self._no_count,
+                'no_count': no_count,
             }
         }
         try:
@@ -115,12 +118,17 @@ class ServiceRoom(Room):
             msg = str(e) or type(e).__name__
             logging.error(f'Failed to send data to hub: {msg}; {asset}')
         else:
-            logging.debug(f'successfully send data to hub; {asset}')
+            logging.debug(f'Successfully send data to hub; {asset}')
 
     async def _run_multi(self, check: CheckBaseMulti, assets: List[Asset]):
         ts = time.time()
         try:
-            results = await check.run(ts, assets)
+            results = await asyncio.wait_for(
+                check.run(ts, assets),
+                timeout=self._max_timeout)
+        except asyncio.TimeoutError:
+            error = CheckException('timed out').to_dict()
+            results = [(None, error)] * len(assets)
         except CheckException as e:
             error = e.to_dict()
             results = [(None, error)] * len(assets)
@@ -130,20 +138,28 @@ class ServiceRoom(Room):
             results = [(None, error)] * len(assets)
 
         for asset, (result, error) in zip(assets, results):
-            await self._send_to_hub(asset, result, error, ts)
+            await self._send_to_hub(asset, result, error, ts, self._no_count)
             await asyncio.sleep(HUB_REQ_SLEEP)
 
     async def _run(self, check: CheckBase, asset: Asset):
         ts = time.time()
+        no_count = self._no_count
+        timeout = min(0.8 * asset.get_interval(), self._max_timeout)
         try:
-            result, error = await check.run(ts, asset)
+            result, error = await asyncio.wait_for(
+                check.run(ts, asset),
+                timeout=timeout)
+        except asyncio.TimeoutError:
+            result, error = None, CheckException('timed out').to_dict()
+        except NoCountException as e:
+            result, error, no_count = e.result, None, True  # Force True
         except CheckException as e:
             result, error = None, e.to_dict()
         except Exception as e:
             msg = str(e) or type(e).__name__
             result, error = None, CheckException(msg).to_dict()
 
-        await self._send_to_hub(asset, result, error, ts)
+        await self._send_to_hub(asset, result, error, ts, no_count)
 
     async def run_loop(self):
         while True:
